#ifndef NT2_INCLUDE_FUNCTIONS_REM_2PI_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REM_2PI_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/rem_2pi.hpp>

#endif
